using GestionIntegral.Api.Models.Suscripciones;
using System.Data;

namespace GestionIntegral.Api.Data.Repositories.Suscripciones
{
    public interface IFacturaRepository
    {
        Task<Factura?> GetByIdAsync(int idFactura);
        Task<IEnumerable<Factura>> GetByIdsAsync(IEnumerable<int> ids);
        Task<IEnumerable<Factura>> GetByPeriodoAsync(string periodo);
        Task<Factura?> GetBySuscriptorYPeriodoAsync(int idSuscriptor, string periodo, IDbTransaction transaction);
        Task<IEnumerable<Factura>> GetListBySuscriptorYPeriodoAsync(int idSuscriptor, string periodo);
        Task<IEnumerable<(Factura Factura, string NombreEmpresa)>> GetFacturasConEmpresaAsync(int idSuscriptor, string periodo);
        Task<Factura?> CreateAsync(Factura nuevaFactura, IDbTransaction transaction);
        Task<bool> UpdateEstadoPagoAsync(int idFactura, string nuevoEstadoPago, IDbTransaction transaction);
        Task<bool> UpdateNumeroFacturaAsync(int idFactura, string numeroFactura, IDbTransaction transaction);
        Task<bool> UpdateLoteDebitoAsync(IEnumerable<int> idsFacturas, int idLoteDebito, IDbTransaction transaction);
        Task<IEnumerable<(Factura Factura, string NombreSuscriptor, int IdEmpresa, decimal TotalPagado)>> GetByPeriodoEnrichedAsync(
        string periodo, string? nombreSuscriptor, string? estadoPago, string? estadoFacturacion, string? tipoFactura);
        Task<bool> UpdateEstadoYMotivoAsync(int idFactura, string nuevoEstadoPago, string? motivoRechazo, IDbTransaction transaction);   
        Task<string?> GetUltimoPeriodoFacturadoAsync();
        Task<IEnumerable<Factura>> GetFacturasPagadasPendientesDeFacturar(string periodo);
    }
}